@@ -18,11 +18,12 @@ __init__.py
 
 from apafib.datasets import fetch_apa_data, load_BCN_IBEX, load_BCN_UK, load_BCN_vuelos, \
      load_medical_costs, load_stroke, load_wind_prediction, load_titanic, load_crabs, \
-          load_life_expectancy, load_electric_devices, load_energy, load_arxiv, load_attrition 
+     load_life_expectancy, load_electric_devices, load_energy, load_arxiv, load_attrition, \
+     load_literature, load_translation, load_heart_failure, load_MNIST
 
 from apafib.classifiers import BlackBoxClassifier, BlackBoxRegressor
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 __all__ = ['fetch_apa_data', 
            'BlackBoxClassifier', 
@@ -39,5 +40,9 @@ __all__ = ['fetch_apa_data',
            'load_electric_devices',
            'load_energy',
            'load_arxiv',
-           'load_attrition'
+           'load_attrition', 
+           'load_literature',
+           'load_translation',
+           'load_heart_failure',
+           'load_MNIST'
            ]
\ No newline at end of file
